library(tidyverse)
library(sf)
library(terra)

source("R/utils.R")

load("data/r_objects/model_data.RData")
load("data/r_objects/sa_polygon.RData")

sa_polygon = sf::st_transform(sa_polygon, crs(model_data))

# ---------------------------------------#
# Plot all presences in the dataset   ####
# ---------------------------------------#
data_extent = ext(model_data)

presences = model_data %>% 
  dplyr::filter(present == 1)

template_raster <- terra::rast(data_extent, resolution = 1000)  # 1000m = 1km
crs(template_raster) <- st_crs(model_data)$wkt

point_counts <- terra::rasterize(
  vect(presences),          
  template_raster,           
  field = NULL,              
  fun = "count",             
  background = 0             
) %>% 
  terra::mask(vect(sa_polygon))

length(which(values(point_counts) > 0)) 

# only 36858 raster cells contain at least 1 presence record 

ggplot() +
  tidyterra::geom_spatraster(data = point_counts, maxcell = 5e7) +
  scale_fill_gradientn(
    colors = c("black", "yellow", "darkred"),
    values = scales::rescale(c(0, 1, max(point_counts_df$count, na.rm = TRUE))),
    breaks = c(0, 1, max(point_counts_df$count, na.rm = TRUE)),
    na.value = "transparent"
  ) +
  geom_sf(data = sa_polygon, fill = NA, color = "gray", size = 0.5) +
  theme_minimal() +
  coord_sf() +
  labs(title = "Coordinate distribution and density")

ggsave("coordinate_density.pdf", path = "plots/", device = "pdf", scale = 4)

# ---------------------------------------#
# Plot all presences in the dataset   ####
# ---------------------------------------#
